#region Using Directives

using System;
using System.Collections;
using System.Configuration;
using System.Data;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.HtmlControls;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;

using ValidationFramework;
using ValidationFramework.Web;

#endregion

public partial class TraditionalForm : System.Web.UI.Page
{

    #region Private Fields

    private Person person;
    private ValidatorGenerator validation = new ValidatorGenerator();

    #endregion


    #region Events

    protected void Page_Load(object sender, EventArgs e)
    {
        validation.AddValidation("txtFirstName", Person.FirstNameMember);
        validation.AddValidation("txtLastName", Person.LastNameMember);
        validation.AddValidation("txtAge", Person.AgeMember);
        validation.AddValidation("txtEmail", Person.EmailAddressMember);
        validation.AddValidation("txtCardNumber", Person.CreditCardNumberMember);
        validation.AddValidation("txtOrderTotal", Person.OrderTotalMember);

        if (!this.IsPostBack)
        {
            this.PopulatePerson();
        }
    }

    protected void OnCreditCardValidate(object sender, ServerValidateEventArgs e)
    {
        CardType cardType = (CardType)Enum.Parse(typeof(CardType), ddlCardType.SelectedValue);

        CustomValidationEventArgs args = Person.IsCreditCardValid(cardType, txtCardNumber.Text);
        e.IsValid = args.IsValid;
        custValCreditCard.ErrorMessage = args.ErrorMessage;
    }

    protected void lnkUpdate_Click(object sender, EventArgs e)
    {
        if (!this.IsValid)
        {
            return;//ASP.NET validators show invalid data
        }

        person = new Person();
        person.FirstName = txtFirstName.Text;
        person.LastName = txtLastName.Text;
        person.Age = Convert.ToInt32(txtAge.Text);
        person.EmailAddress = txtEmail.Text;
        person.CardType = (CardType)Enum.Parse(typeof(CardType), ddlCardType.SelectedValue);
        person.CreditCardNumber = txtCardNumber.Text;
        person.OrderTotal = Convert.ToDecimal(txtOrderTotal.Text);

        new PersonMapper().SaveItem(person);
    }

    #endregion


    #region Private Methods

    private void PopulatePerson()
    {
        person = new PersonMapper().GetItem(1);
        txtFirstName.Text = person.FirstName;
        txtLastName.Text = person.LastName;
        txtAge.Text = person.Age.ToString();
        txtEmail.Text = person.EmailAddress;
        ddlCardType.SelectedValue = person.CardType.ToString();
        txtCardNumber.Text = person.CreditCardNumber;
        txtOrderTotal.Text = person.OrderTotal.ToString();

        validation.GenerateValidators(this, person);
    }

    #endregion

}
