#region Using Directives

using System;
using System.Collections.Generic;
using System.Text;

#endregion

namespace ValidationDemo.Win
{
    /// <summary>
    /// An object instance of this class will represent an individual item that will
    /// be used (typically) in a dropdown list.  It is essentially a Name/Value
    /// pair where the value item is a generic type.  This gives the ability
    /// for the value to be int, byte, Guid, etc.  Since it is generic, this
    /// gives the ability to have a high-performance structure that avoids
    /// all of the excrutiating boxing/unboxing that would have had to happen in
    /// the 1.1 framework.
    /// Author: Steve Michelotti
    /// </summary>
    /// <typeparam name="T">Type specified for Value property</typeparam>
    [Serializable]
    public class DataListItem<T>
    {

        #region Private Fields

        private T dataValue;
        private string text;

        #endregion


        #region Constructors

        public DataListItem(T value, string dataText)
        {
            dataValue = value;
            text = dataText;
        }

        #endregion


        #region Public Properties

        public T Value
        {
            get
            {
                return dataValue;
            }
        }

        public string Text
        {
            get
            {
                return text;
            }
        }

        #endregion


        #region Overrides

        public override string ToString()
        {
            //Make this return the Text because data binding uses ToString() by default
            return this.Text;
        }

        public override int GetHashCode()
        {
            return this.dataValue.GetHashCode();
        }

        public override bool Equals(object obj)
        {
            DataListItem<T> itemToCompare = obj as DataListItem<T>;
            if (itemToCompare != null)
            {
                return (this.Value.Equals(itemToCompare.Value) && this.Text.Equals(itemToCompare.Text));
            }
            else
            {
                return false;
            }
        }

        #endregion

    }
}
