#region Using Directives

using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Text;
using System.Windows.Forms;

#endregion

namespace ValidationDemo.Win
{
    public partial class MainForm : ValidationDemo.Win.ValidatableForm
    {

        #region Private Fields

        private Person person;

        #endregion


        #region Constructor

        public MainForm()
        {
            InitializeComponent();
        }

        #endregion


        #region Events

        protected override void OnLoad(EventArgs e)
        {
            this.BindCardType();
            this.InitializePerson();
            this.BindPerson();

            base.OnLoad(e);
        }

        private void btnOK_Click(object sender, EventArgs e)
        {
            //If no custom validators are used, then calling ValidateAllControls()
            //should be unnecessary.
            this.ValidateAllControls();

            MessageBox.Show("Person IsValid: " + person.IsValid.ToString());
            if (!person.IsValid)
            {
                MessageBox.Show((person as IDataErrorInfo).Error, "Error Messages", MessageBoxButtons.OK, MessageBoxIcon.Information);
            }
        }

        #endregion


        #region Private Methods

        private void BindCardType()
        {
            DataListBindingCollection<CardType> cardList = new DataListBindingCollection<CardType>();
            cardList.Add(CardType.Visa, "Visa");
            cardList.Add(CardType.MasterCard, "MasterCard");
            cardList.Add(CardType.Amex, "Amex");
            cardList.BindControl(cboCardType);
        }

        private void InitializePerson()
        {
            person = new Person();
            person.FirstName = "Steve";
            person.LastName = "Michelotti";
            person.Age = 31;
            person.EmailAddress = "steve.michelotti@emagination.com";
            person.CardType = CardType.Visa;
            person.CreditCardNumber = "1234567890123456";
            person.OrderTotal = 21.99M;
        }

        private void BindPerson()
        {
            Bind(txtFirstName, "Text", person, Person.FirstNameMember);
            Bind(txtLastName, "Text", person, Person.LastNameMember);
            Bind(txtAge, "Text", person, Person.AgeMember);
            Bind(txtEmail, "Text", person, Person.EmailAddressMember);
            Bind(cboCardType, "SelectedValue", person, Person.CardTypeMember);
            Bind(txtCardNumber, "Text", person, Person.CreditCardNumberMember);
            Bind(txtOrderPrice, "Text", person, Person.OrderTotalMember);
        }

        #endregion

    }
}

