#region Using Directives

using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Text;
using System.Windows.Forms;

#endregion

namespace ValidationDemo.Win
{
    public partial class ValidatableForm : Form
    {

        #region Constructors

        public ValidatableForm()
        {
            InitializeComponent();
        }

        #endregion


        #region Protected Methods

        protected void Bind(Control ctl, string ctlProp, object dataSource, string dataMember)
        {
            if (ctl == null)
            {
                throw new ArgumentNullException("ctl", "ctl cannot be null");
            }

            ctl.DataBindings.Add(ctlProp, dataSource, dataMember);
            ctl.Validated += OnControlValidated;
        }

        #endregion


        #region Private Methods

        /// <summary>
        /// Optionally, can bind a control's validated event to this method
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void OnControlValidated(object sender, EventArgs e)
        {
            Control ctl = sender as Control;
            ValidateControl(ctl);
        }

        
        /// <summary>
        /// This method is where all the "magic" happens since the Person object
        /// implements the IDataErrorInfo interface.
        /// </summary>
        /// <param name="ctl"></param>
        private void ValidateControl(Control ctl)
        {
            foreach (Binding binding in ctl.DataBindings)
            {
                if (binding.IsBinding)
                {
                    IDataErrorInfo errorInfo = binding.DataSource as IDataErrorInfo;
                    error.SetError(ctl, errorInfo[binding.BindingMemberInfo.BindingField]);
                }
            }
        }

        /// <summary>
        /// Performs validation for all controls on the screen.
        /// </summary>
        internal void ValidateAllControls()
        {
            ValidateSingleControl(this);
        }


        /// <summary>
        /// Recursively validate all controls on form
        /// </summary>
        /// <param name="currentControl">Current control to validate.</param>
        private void ValidateSingleControl(Control currentControl)
        {
            ValidateControl(currentControl);
            foreach (Control childControl in currentControl.Controls)
            {
                ValidateSingleControl(childControl);
            }
        }

        #endregion

    }
}