#region Using Directives

using System;
using System.Collections.Generic;
using System.Text;

using NUnit.Framework;

#endregion

namespace ValidationFramework.Tests
{
    [TestFixture]
    public class CompareValidationTestFixture
    {

        #region Int Compare

        [Test]
        public void TestIntCompare()
        {
            Assert.IsTrue(true);

            IntFoo foo = new IntFoo();
            foo.Bar = 5;
            Assert.IsFalse(foo.IsValid, "Compare Validation - foo should not be valid");

            foo.Bar = 15;
            Assert.IsTrue(foo.IsValid, "Compare Validation - foo should be valid");
        }

        class IntFoo : ValidatableBase
        {
            private int bar;

            [CompareValidator(10, ValidationCompareOperator.GreaterThan, "Bar must be greater than 10.")]
            public int Bar
            {
                get
                {
                    return bar;
                }
                set
                {
                    bar = value;
                }
            }
        }

        #endregion


        #region String Compare

        [Test]
        public void TestStringCompare()
        {
            Assert.IsTrue(true);

            StringFoo foo = new StringFoo();
            foo.Bar = "123";
            Assert.IsFalse(foo.IsValid, "Compare Validation - foo should not be valid");

            foo.Bar = "abc";
            Assert.IsTrue(foo.IsValid, "Compare Validation - foo should be valid");
        }

        class StringFoo : ValidatableBase
        {
            private string bar;

            [CompareValidator("abc", ValidationCompareOperator.Equal, "Bar must be equal abc.")]
            public string Bar
            {
                get
                {
                    return bar;
                }
                set
                {
                    bar = value;
                }
            }
        }

        #endregion


        #region Date Compare

        [Test]
        public void TestDateCompare()
        {
            Assert.IsTrue(true);

            DateFoo foo = new DateFoo();
            foo.Bar = new DateTime(2005, 1, 1);
            Assert.IsFalse(foo.IsValid, "Compare Validation - foo should not be valid");

            foo.Bar = new DateTime(2007, 1, 1);
            Assert.IsTrue(foo.IsValid, "Compare Validation - foo should be valid");
        }

        class DateFoo : ValidatableBase
        {
            private DateTime bar;

            [CompareValidator("1/1/2006", ValidationCompareOperator.GreaterThan, "Bar must be greater than 1/1/2006.")]
            public DateTime Bar
            {
                get
                {
                    return bar;
                }
                set
                {
                    bar = value;
                }
            }
        }

        #endregion


        #region Decimal Compare

        [Test]
        public void TestDecimalCompare()
        {
            Assert.IsTrue(true);

            DecimalFoo foo = new DecimalFoo();
            foo.Bar = 5M;
            Assert.IsFalse(foo.IsValid, "Compare Validation - foo should not be valid");

            foo.Bar = 15M;
            Assert.IsTrue(foo.IsValid, "Compare Validation - foo should be valid");
        }

        class DecimalFoo : ValidatableBase
        {
            private decimal bar;

            [CompareValidator(10, ValidationCompareOperator.GreaterThan, "Bar must be greater than 10.")]
            public decimal Bar
            {
                get
                {
                    return bar;
                }
                set
                {
                    bar = value;
                }
            }
        }

        #endregion


        #region Double Compare

        [Test]
        public void TestDoubleCompare()
        {
            Assert.IsTrue(true);

            DoubleFoo foo = new DoubleFoo();
            foo.Bar = 5;
            Assert.IsFalse(foo.IsValid, "Compare Validation - foo should not be valid");

            foo.Bar = 15;
            Assert.IsTrue(foo.IsValid, "Compare Validation - foo should be valid");
        }

        class DoubleFoo : ValidatableBase
        {
            private double bar;

            [CompareValidator(10, ValidationCompareOperator.GreaterThan, "Bar must be greater than 10.")]
            public double Bar
            {
                get
                {
                    return bar;
                }
                set
                {
                    bar = value;
                }
            }
        }

        #endregion


        #region Nullable Int Compare

        [Test]
        public void TestNullableIntCompare()
        {
            Assert.IsTrue(true);

            NullableIntFoo foo = new NullableIntFoo();
            foo.Bar = 5;
            Assert.IsFalse(foo.IsValid, "Compare Validation - foo should not be valid");

            foo.Bar = 15;
            Assert.IsTrue(foo.IsValid, "Compare Validation - foo should be valid");

            foo.Bar = null;
            Assert.IsTrue(foo.IsValid, "Compare Validation - foo should be valid");
        }

        class NullableIntFoo : ValidatableBase
        {
            private int? bar;

            [CompareValidator(10, ValidationCompareOperator.GreaterThan, "Bar must be greater than 10.")]
            public int? Bar
            {
                get
                {
                    return bar;
                }
                set
                {
                    bar = value;
                }
            }
        }

        #endregion


        #region Nullable Date Compare

        [Test]
        public void TestNullableDateCompare()
        {
            Assert.IsTrue(true);

            NullableDateFoo foo = new NullableDateFoo();
            foo.Bar = new DateTime(2005, 1, 1);
            Assert.IsFalse(foo.IsValid, "Compare Validation - foo should not be valid");

            foo.Bar = new DateTime(2007, 1, 1);
            Assert.IsTrue(foo.IsValid, "Compare Validation - foo should be valid");

            foo.Bar = null;
            Assert.IsTrue(foo.IsValid, "Compare Validation - foo should be valid");
        }

        class NullableDateFoo : ValidatableBase
        {
            private DateTime? bar;

            [CompareValidator("1/1/2006", ValidationCompareOperator.GreaterThan, "Bar must be greater than 1/1/2006.")]
            public DateTime? Bar
            {
                get
                {
                    return bar;
                }
                set
                {
                    bar = value;
                }
            }
        }

        #endregion


        #region Nullable Decimal Compare

        [Test]
        public void TestNullableDecimalCompare()
        {
            Assert.IsTrue(true);

            NullableDecimalFoo foo = new NullableDecimalFoo();
            foo.Bar = 5M;
            Assert.IsFalse(foo.IsValid, "Compare Validation - foo should not be valid");

            foo.Bar = 15M;
            Assert.IsTrue(foo.IsValid, "Compare Validation - foo should be valid");

            foo.Bar = null;
            Assert.IsTrue(foo.IsValid, "Compare Validation - foo should be valid");
        }

        class NullableDecimalFoo : ValidatableBase
        {
            private decimal? bar;

            [CompareValidator(10, ValidationCompareOperator.GreaterThan, "Bar must be greater than 10.")]
            public decimal? Bar
            {
                get
                {
                    return bar;
                }
                set
                {
                    bar = value;
                }
            }
        }

        #endregion


        #region Nullable Double Compare

        [Test]
        public void TestNullableDoubleCompare()
        {
            Assert.IsTrue(true);

            NullableDoubleFoo foo = new NullableDoubleFoo();
            foo.Bar = 5;
            Assert.IsFalse(foo.IsValid, "Compare Validation - foo should not be valid");

            foo.Bar = 15;
            Assert.IsTrue(foo.IsValid, "Compare Validation - foo should be valid");

            foo.Bar = null;
            Assert.IsTrue(foo.IsValid, "Compare Validation - foo should be valid");
        }

        class NullableDoubleFoo : ValidatableBase
        {
            private double? bar;

            [CompareValidator(10, ValidationCompareOperator.GreaterThan, "Bar must be greater than 10.")]
            public double? Bar
            {
                get
                {
                    return bar;
                }
                set
                {
                    bar = value;
                }
            }
        }

        #endregion

    }
}
