#region Using Directives

using System;
using System.Collections.Generic;
using System.Text;

using ValidationFramework;

using NUnit.Framework;

#endregion

namespace ValidationFramework.Tests
{
    [TestFixture]
    public class RangeValidationTestFixture
    {

        #region Int Range

        [Test]
        public void TestIntRange()
        {
            Assert.IsTrue(true);

            IntFoo foo = new IntFoo();
            foo.Bar = 25;
            Assert.IsFalse(foo.IsValid, "Range Validation - foo should not be valid");

            foo.Bar = 15;
            Assert.IsTrue(foo.IsValid, "Range Validation - foo should be valid");
        }

        class IntFoo : ValidatableBase
        {
            private int bar;

            [RangeValidator(10, 20, "Bar must be between 10-20.")]
            public int Bar
            {
                get
                {
                    return bar;
                }
                set
                {
                    bar = value;
                }
            }
        }
      
        #endregion


        #region String Range

        [Test]
        public void TestStringRange()
        {
            Assert.IsTrue(true);

            StringFoo foo = new StringFoo();
            foo.Bar = "z";
            Assert.IsFalse(foo.IsValid, "Range Validation - foo should not be valid");

            foo.Bar = "j";
            Assert.IsTrue(foo.IsValid, "Range Validation - foo should be valid");
        }

        class StringFoo : ValidatableBase
        {
            private string bar;

            [RangeValidator("a", "m", "Bar must be between a-m.")]
            public string Bar
            {
                get
                {
                    return bar;
                }
                set
                {
                    bar = value;
                }
            }
        }

        #endregion


        #region Date Range

        [Test]
        public void TestDateRange()
        {
            Assert.IsTrue(true);

            DateFoo foo = new DateFoo();
            foo.Bar = new DateTime(2006, 10, 1);
            Assert.IsFalse(foo.IsValid, "Range Validation - foo should not be valid");

            foo.Bar = new DateTime(2006, 4, 1);
            Assert.IsTrue(foo.IsValid, "Range Validation - foo should be valid");
        }

        class DateFoo : ValidatableBase
        {
            private DateTime bar;

            [RangeValidator("1/1/2006", "7/1/2006", "Bar must be between 1/1/06-7/1/06.")]
            public DateTime Bar
            {
                get
                {
                    return bar;
                }
                set
                {
                    bar = value;
                }
            }
        }

        #endregion


        #region Decimal Range

        [Test]
        public void TestDecimalRange()
        {
            Assert.IsTrue(true);

            DecimalFoo foo = new DecimalFoo();
            foo.Bar = 21.4M;
            Assert.IsFalse(foo.IsValid, "Range Validation - foo should not be valid");

            foo.Bar = 10.5M;
            Assert.IsTrue(foo.IsValid, "Range Validation - foo should be valid");
        }

        class DecimalFoo : ValidatableBase
        {
            private Decimal bar;

            [RangeValidator(10.1, 10.9, "Bar must be between 10.1-10.9.")]
            public Decimal Bar
            {
                get
                {
                    return bar;
                }
                set
                {
                    bar = value;
                }
            }
        }

        #endregion


        #region Double Range

        [Test]
        public void TestDoubleRange()
        {
            Assert.IsTrue(true);

            DoubleFoo foo = new DoubleFoo();
            foo.Bar = 25;
            Assert.IsFalse(foo.IsValid, "Range Validation - foo should not be valid");

            foo.Bar = 15;
            Assert.IsTrue(foo.IsValid, "Range Validation - foo should be valid");
        }

        class DoubleFoo : ValidatableBase
        {
            private double bar;

            [RangeValidator(10, 20, "Bar must be between 10-20.")]
            public double Bar
            {
                get
                {
                    return bar;
                }
                set
                {
                    bar = value;
                }
            }
        }

        #endregion


        #region Nullable Int Range

        [Test]
        public void TestNullableIntRange()
        {
            Assert.IsTrue(true);

            NullableIntFoo foo = new NullableIntFoo();
            foo.Bar = 25;
            Assert.IsFalse(foo.IsValid, "Range Validation - foo should not be valid");

            foo.Bar = 15;
            Assert.IsTrue(foo.IsValid, "Range Validation - foo should be valid");

            foo.Bar = null;
            Assert.IsTrue(foo.IsValid, "Range Validation - foo should be valid");
        }

        class NullableIntFoo : ValidatableBase
        {
            private int? bar;

            [RangeValidator(10, 20, "Bar must be between 10-20.")]
            public int? Bar
            {
                get
                {
                    return bar;
                }
                set
                {
                    bar = value;
                }
            }
        }

        #endregion


        #region Nullable Date Range

        [Test]
        public void TestNullableDateRange()
        {
            Assert.IsTrue(true);

            NullableDateFoo foo = new NullableDateFoo();
            foo.Bar = new DateTime(2006, 10, 1);
            Assert.IsFalse(foo.IsValid, "Range Validation - foo should not be valid");

            foo.Bar = new DateTime(2006, 4, 1);
            Assert.IsTrue(foo.IsValid, "Range Validation - foo should be valid");

            foo.Bar = null;
            Assert.IsTrue(foo.IsValid, "Range Validation - foo should be valid");
        }

        class NullableDateFoo : ValidatableBase
        {
            private DateTime? bar;

            [RangeValidator("1/1/2006", "7/1/2006", "Bar must be between 1/1/06-7/1/06.")]
            public DateTime? Bar
            {
                get
                {
                    return bar;
                }
                set
                {
                    bar = value;
                }
            }
        }

        #endregion


        #region Nullable Decimal Range

        [Test]
        public void TestNullableDecimalRange()
        {
            Assert.IsTrue(true);

            NullableDecimalFoo foo = new NullableDecimalFoo();
            foo.Bar = 21.4M;
            Assert.IsFalse(foo.IsValid, "Range Validation - foo should not be valid");

            foo.Bar = 10.5M;
            Assert.IsTrue(foo.IsValid, "Range Validation - foo should be valid");

            foo.Bar = null;
            Assert.IsTrue(foo.IsValid, "Range Validation - foo should be valid");
        }

        class NullableDecimalFoo : ValidatableBase
        {
            private Decimal? bar;

            [RangeValidator(10.1, 10.9, "Bar must be between 10.1-10.9.")]
            public Decimal? Bar
            {
                get
                {
                    return bar;
                }
                set
                {
                    bar = value;
                }
            }
        }

        #endregion


        #region Nullable Double Range

        [Test]
        public void TestNullableDoubleRange()
        {
            Assert.IsTrue(true);

            NullableDoubleFoo foo = new NullableDoubleFoo();
            foo.Bar = 25;
            Assert.IsFalse(foo.IsValid, "Range Validation - foo should not be valid");

            foo.Bar = 15;
            Assert.IsTrue(foo.IsValid, "Range Validation - foo should be valid");

            foo.Bar = null;
            Assert.IsTrue(foo.IsValid, "Range Validation - foo should be valid");
        }

        class NullableDoubleFoo : ValidatableBase
        {
            private double? bar;

            [RangeValidator(10, 20, "Bar must be between 10-20.")]
            public double? Bar
            {
                get
                {
                    return bar;
                }
                set
                {
                    bar = value;
                }
            }
        }

        #endregion

    }
}
