#region Using Directives

using System;
using ValidationFramework;
using NUnit.Framework;

#endregion

namespace ValidationFramework.Tests
{
    
    [TestFixture]
    public class TestRequiredFixture
    {

        #region Required Test Methods

        [Test]
        public void TestIntRequired()
        {
            RequiredItem item = new RequiredItem();
            string err = GetErrorMessage("IntData", item);
            Assert.IsFalse(string.IsNullOrEmpty(err), "IntData should fail required validation");
        }

        [Test]
        public void TestIntRequiredPass()
        {
            RequiredItem item = new RequiredItem();
            item.IntData = 21;
            string err = GetErrorMessage("IntData", item);
            Assert.IsTrue(string.IsNullOrEmpty(err), "IntData should pass required validation");
        }

        [Test]
        public void TestIntRequiredInitValue()
        {
            RequiredItemInitValue item = new RequiredItemInitValue();
            item.IntData = 21;
            string err = GetErrorMessage("IntData", item);
            Assert.IsFalse(string.IsNullOrEmpty(err), "IntData should fail required validation");
        }

        [Test]
        public void TestIntRequiredInitValuePass()
        {
            RequiredItemInitValue item = new RequiredItemInitValue();
            item.IntData = 22;
            string err = GetErrorMessage("IntData", item);
            Assert.IsTrue(string.IsNullOrEmpty(err), "IntData should pass required validation");
        }

        [Test]
        public void TestStringRequiredNull()
        {
            RequiredItem item = new RequiredItem();
            string err = GetErrorMessage("StringData", item);
            Assert.IsFalse(string.IsNullOrEmpty(err), "StringData should pass required validation");
        }

        [Test]
        public void TestStringRequiredEmpty()
        {
            RequiredItem item = new RequiredItem();
            string err = GetErrorMessage("StringData", item);
            Assert.IsFalse(string.IsNullOrEmpty(err), "StringData should pass required validation");
        }

        [Test]
        public void TestStringRequiredPass()
        {
            RequiredItem item = new RequiredItem();
            item.StringData = "abc";
            string err = GetErrorMessage("StringData", item);
            Assert.IsTrue(string.IsNullOrEmpty(err), "StringData should pass required validation");
        }

        [Test]
        public void TestStringRequiredInitValue()
        {
            RequiredItemInitValue item = new RequiredItemInitValue();
            item.StringData = "abc";
            string err = GetErrorMessage("StringData", item);
            Assert.IsFalse(string.IsNullOrEmpty(err), "StringData should fail required validation");
        }

        [Test]
        public void TestStringRequiredInitValuePass()
        {
            RequiredItemInitValue item = new RequiredItemInitValue();
            item.StringData = "123";
            string err = GetErrorMessage("StringData", item);
            Assert.IsTrue(string.IsNullOrEmpty(err), "StringData should pass required validation");
        }

        #endregion


        #region Private Utility Methods

        private string GetErrorMessage(string propertyName, RequiredItem item)
        {
            ValidationManager validator = new ValidationManager(item);
            validator.Validate(propertyName);
            string err = validator.GetErrorMessages(propertyName);
            Console.WriteLine(propertyName + " - " + err);
            return err;
        }

        private string GetErrorMessage(string propertyName, RequiredItemInitValue item)
        {
            ValidationManager validator = new ValidationManager(item);
            validator.Validate(propertyName);
            string err = validator.GetErrorMessages(propertyName);
            Console.WriteLine(propertyName + " - " + err);
            return err;
        }

        #endregion

    }
}
