#region Using Directives

using System;
using System.Collections.Generic;
using System.Text;

using ValidationFramework;

using NUnit.Framework;

#endregion

namespace ValidationFramework.Tests
{
    [TestFixture]
    public class ValidationTestFixture
    {

        [Test]
        public void TestRequiredInt()
        {
            int val1 = 0;
            int val2 = 21;
            Assert.IsFalse(Validation.IsRequiredValid(val1), "val1 should fail validation");
            Assert.IsTrue(Validation.IsRequiredValid(val2), "val2 should pass validation");
        }

        [Test]
        public void TestRequiredIntInitValue()
        {
            int value = 21;
            Assert.IsFalse(Validation.IsRequiredValid(value, 21), "value should fail validatioin");
            Assert.IsTrue(Validation.IsRequiredValid(value, 22), "value should pass validation");
        }

        [Test]
        public void TestRequiredNullableDate()
        {
            DateTime? val1 = null;
            DateTime? val2 = new DateTime(2006, 1, 1);
            Assert.IsFalse(Validation.IsRequiredValid(val1), "val1 should fail validation");
            Assert.IsTrue(Validation.IsRequiredValid(val2), "val2 should pass validation");
        }

        [Test]
        public void TestRequiredString()
        {
            string val1 = null;
            string val2 = "test";
            Assert.IsFalse(Validation.IsRequiredValid(val1), "val1 should fail validation");
            Assert.IsTrue(Validation.IsRequiredValid(val2), "val2 should pass validation");
        }

        [Test]
        public void TestRequiredStringInitValue()
        {
            string value = "abc";
            Assert.IsFalse(Validation.IsRequiredValid(value, "abc"), "value should fail validation");
            Assert.IsTrue(Validation.IsRequiredValid(value, "123"), "value should pass validation");
        }

        [Test]
        public void TestCompareInt()
        {
            int val1 = 21;
            int val2 = 22;
            Assert.IsFalse(Validation.IsCompareValid(val1, val2, ValidationCompareOperator.GreaterThan), "val1 should fail validation");
            Assert.IsTrue(Validation.IsCompareValid(val1, val2, ValidationCompareOperator.LessThanEqual), "val2 should pass validation");
            Assert.IsTrue(Validation.IsCompareValid(val1, 21, ValidationCompareOperator.Equal), "val2 should pass validation");
            Assert.IsTrue(Validation.IsCompareValid(val1, 33, ValidationCompareOperator.NotEqual), "val2 should pass validation");
        }

        [Test]
        public void TestCompareNullableDate()
        {
            DateTime? val1 = null;
            DateTime? val2 = new DateTime(2006, 1, 1);
            DateTime? val3 = new DateTime(2005, 1, 1);
            Assert.IsFalse(Validation.IsCompareValid(val2, val3, ValidationCompareOperator.LessThan), "should fail validation");
            Assert.IsTrue(Validation.IsCompareValid(val2, val3, ValidationCompareOperator.GreaterThanEqual), "should pass validation");
            Assert.IsTrue(Validation.IsCompareValid(val1, val2, ValidationCompareOperator.NotEqual), "should pass validation");
        }

        [Test]
        public void TestCompareString()
        {
            string a = "a";
            string b = "b";
            Assert.IsFalse(Validation.IsCompareValid(a, b, ValidationCompareOperator.GreaterThan), "string compare should fail validation");
            Assert.IsTrue(Validation.IsCompareValid(a, b, ValidationCompareOperator.LessThan), "string compare should pass validation");
        }

        [Test]
        public void TestRangeInt()
        {
            int val1 = 11;
            Assert.IsFalse(Validation.IsRangeValid(val1, 1, 10), "val1 should fail validation");
            Assert.IsTrue(Validation.IsRangeValid(val1, 1, 20), "val1 should pass validation");
        }

        [Test]
        public void TestRangeNullableDate()
        {
            DateTime? val1 = null;
            DateTime? val2 = new DateTime(2005, 6, 6);
            DateTime val2006 = new DateTime(2006, 1, 1);
            DateTime val2005 = new DateTime(2005, 1, 1);
            Assert.IsTrue(Validation.IsRangeValid(val1, val2005, val2006), "val should pass validation");
            Assert.IsTrue(Validation.IsRangeValid(val2, val2005, val2006), "val should pass validation");
            Assert.IsFalse(Validation.IsRangeValid(val2, new DateTime(2005, 8, 8), val2006), "val should fail validaton");
        }

        [Test]
        public void TestRangeString()
        {
            Assert.IsFalse(Validation.IsRangeValid("a", "b", "c"), "should fail validation");
            Assert.IsTrue(Validation.IsRangeValid("b", "a", "c"), "should pass validation");
        }

        [Test]
        public void TestLength()
        {
            string test = "test";
            Assert.IsFalse(Validation.IsLengthValid(test, 3), "should fail length validation");
            Assert.IsTrue(Validation.IsLengthValid(test, 4), "should pass length validation");
            Assert.IsTrue(Validation.IsLengthValid(test, 5), "should pass length validation");
        }

        [Test]
        public void TestRegex()
        {
        }


    }
}
