#region Using Directives

using System;
using System.Collections.Generic;
using System.Collections.ObjectModel;
using System.Text;

#endregion

namespace ValidationFramework
{
    public class ValidatableCollection<T> : Collection<T>, IValid where T : ValidatableBase
    {
        
        #region IValid Members

        public virtual bool IsValid
        {
            get 
            {
                bool isValid = true;

                //Check to see if each item is valid.
                //Even if an invalid item is found, continue to check for the rest
                //of the items so that all error messages can be accumulated.
                foreach (T item in this)
                {
                    if (!item.IsValid)
                    {
                        isValid = false;
                    }
                }
                return isValid;
            }
        }

        public IEnumerable<string> ValidationMessages
        {
            get
            {
                List<string> errorList = new List<string>();
                foreach (T item in this)
                {
                    errorList.AddRange(item.ValidationMessages);
                }
                return errorList;
            }
        }

        //public string GetValidationMessages(string separator)
        //{
        //    List<string> errorList = new List<string>();
        //    foreach (T item in this)
        //    {
        //        errorList.Add(item.GetValidationMessages(separator));
        //    }
        //    return string.Join(separator, errorList.ToArray());
        //}

        #endregion

    }
}
