#region Using Directives

using System;

#endregion

namespace ValidationFramework
{
	/// <summary>
	/// Performs a comparison validation.
	/// Author: Steve Michelotti
	/// </summary>
	[AttributeUsage(AttributeTargets.Property)]
    public sealed class CompareValidatorAttribute : ValidatorAttribute
	{

		#region Private Fields

		private object comparisonValue;
		private ValidationCompareOperator oper;

		#endregion


		#region Public Properties

		public object ValueToCompare
		{
			get
			{
				return this.comparisonValue;
			}
		}

		public ValidationCompareOperator ValidationOperator
		{
			get
			{
				return this.oper;
			}
		}

		#endregion


		#region Constructors

		public CompareValidatorAttribute(object valueToCompare, ValidationCompareOperator validationOperator, string errorMessage) : base(errorMessage)
		{
			this.comparisonValue = valueToCompare;
			this.oper = validationOperator;
		}

		#endregion
		
		
		#region Protected Overrides

        protected internal override bool EvaluateIsValid()
		{
            if (this.PropertyToValidate.Value == null || this.comparisonValue == null)
				return true;

            if (PropertyToValidate.Type == typeof(string))
            {
                string comparison = this.comparisonValue.ToString();
                string value = this.PropertyToValidate.Value.ToString();
                return Validation.IsCompareValid(value, comparison, this.ValidationOperator);
            }
            else if (PropertyToValidate.Type == typeof(int))
            {
                int comparison = Convert.ToInt32(this.comparisonValue);
                int value = Convert.ToInt32(this.PropertyToValidate.Value);
                return Validation.IsCompareValid(value, comparison, this.ValidationOperator);
            }
            else if (PropertyToValidate.Type == typeof(decimal))
            {
                decimal comparison = Convert.ToDecimal(this.comparisonValue);
                decimal value = Convert.ToDecimal(this.PropertyToValidate.Value);
                return Validation.IsCompareValid(value, comparison, this.ValidationOperator);
            }
            else if (PropertyToValidate.Type == typeof(DateTime))
            {
                DateTime comparison = Convert.ToDateTime(this.comparisonValue);
                DateTime value = Convert.ToDateTime(this.PropertyToValidate.Value);
                return Validation.IsCompareValid(value, comparison, this.ValidationOperator);
            }
            else if (PropertyToValidate.Type == typeof(double))
            {
                double comparison = Convert.ToDouble(this.comparisonValue);
                double value = Convert.ToDouble(this.PropertyToValidate.Value);
                return Validation.IsCompareValid(value, comparison, this.ValidationOperator);
            }
            else if (PropertyToValidate.Type == typeof(Nullable<int>))
            {
                Nullable<int> comparison = Convert.ToInt32(this.comparisonValue);
                Nullable<int> value = (Nullable<int>)this.PropertyToValidate.Value;
                return Validation.IsCompareValid(value, comparison, this.ValidationOperator);
            }
            else if (PropertyToValidate.Type == typeof(Nullable<DateTime>))
            {
                Nullable<DateTime> comparison = Convert.ToDateTime(this.comparisonValue);
                Nullable<DateTime> value = (Nullable<DateTime>)this.PropertyToValidate.Value;
                return Validation.IsCompareValid(value, comparison, this.ValidationOperator);
            }
            else if (PropertyToValidate.Type == typeof(Nullable<decimal>))
            {
                Nullable<decimal> comparison = Convert.ToDecimal(this.comparisonValue);
                Nullable<decimal> value = (Nullable<decimal>)this.PropertyToValidate.Value;
                return Validation.IsCompareValid(value, comparison, this.ValidationOperator);
            }
            else if (PropertyToValidate.Type == typeof(Nullable<double>))
            {
                Nullable<double> comparison = Convert.ToDouble(this.comparisonValue);
                Nullable<double> value = (Nullable<double>)this.PropertyToValidate.Value;
                return Validation.IsCompareValid(value, comparison, this.ValidationOperator);
            }
            else
            {
                throw new ArgumentException(PropertyToValidate.Type.ToString() +
                    " is not a valid data type to be used with a Range Validator.");
            }
		}

		#endregion

	}//end class
}//end namespace
