#region Using Directives

using System;
using System.Reflection;

#endregion

namespace ValidationFramework
{
	/// <summary>
	/// Performs a custom validation via an System.EventHandler&lt;T&gt; delegate.
	/// Author: Steve Michelotti
	/// </summary>
	[AttributeUsage(AttributeTargets.Property)]
	public sealed class CustomValidatorAttribute : ValidatorAttribute
	{

		#region Private Fields

		private string methodToRun;

		#endregion


		#region Public Properties

		public string ValidationMethod
		{
			get
			{
				return this.methodToRun;
			}
		}

        public override string UniqueKey
        {
            get
            {
                return this.methodToRun;
            }
        }

		#endregion


		#region Constructors

		public CustomValidatorAttribute(string errorMessage, string validationMethod) : base(errorMessage)
		{
			this.methodToRun = validationMethod;
		}

		#endregion
		
		
		#region Protected Overrides

        protected internal override bool EvaluateIsValid()
        {
            EventHandler<CustomValidationEventArgs> handler =
                Delegate.CreateDelegate(typeof(EventHandler<CustomValidationEventArgs>), 
                this.PropertyToValidate.Target, 
                this.ValidationMethod) as EventHandler<CustomValidationEventArgs>;

            CustomValidationEventArgs args = new CustomValidationEventArgs();
            handler(this, args);

            this.errMessage = args.ErrorMessage;
            return args.IsValid;
        }

		#endregion

    }//end class
}//end namespace
