#region Using Directives

using System;

#endregion

namespace ValidationFramework
{
	/// <summary>
	/// Performs a string length validation.
	/// </summary>
	[AttributeUsage(AttributeTargets.Property)]
	public sealed class LengthValidatorAttribute : ValidatorAttribute
	{

		#region Private Fields

		private readonly int min;
		private readonly int max;

		#endregion


		#region Public Properties

		public int Maximum
		{
			get { return this.max; }
		}

		public int Minimum
		{
			get { return this.min; }
		}

		#endregion


		#region Constructor

		public LengthValidatorAttribute(int minimum, int maximum, string errorMessage) : base(errorMessage)
		{
			this.min = minimum;
			this.max = maximum;
		}

		public LengthValidatorAttribute(int maximum, string errorMessage) : this(0, maximum, errorMessage)
		{
		}

		#endregion


		#region Protected Overrides

        protected internal override bool EvaluateIsValid()
        {
            if (this.PropertyToValidate.Type != typeof(string))
            {
                throw new ArgumentException("Property must be a string to be used for the Length Validator");
            }

            string text = this.PropertyToValidate.Value as string;
            return Validation.IsLengthValid(text, this.min, this.max);
        }

		#endregion

	}//end class
}//end namespace
