#region Using Directives

using System;
using System.Collections.Generic;
using System.Reflection;

#endregion

namespace ValidationFramework
{
    /// <summary>
    /// Extends PropertyInfo by wrapping a PropertyInfo object along with the object
    /// instanace that the Property belongs to.  This allows for "stateful" reflection.
    /// </summary>
    public class PropertyInfoExtended
    {

        #region Private Fields

        private PropertyInfo propInfo;
        private object target;

        #endregion


        #region Public Properties

        public string Name
        {
            get
            {
                return this.propInfo.Name;
            }
        }

        public object Value
        {
            get
            {
                return this.propInfo.GetValue(target, null);
            }
        }

        public Type Type
        {
            get
            {
                return this.propInfo.PropertyType;
            }
        }
        
        public object Target
        {
            get
            {
                return this.target;
            }
        }

        #endregion


        #region Constructors

        public PropertyInfoExtended(PropertyInfo propertyInfo, object targetInstance)
        {
            this.propInfo = propertyInfo;
            this.target = targetInstance;
        }

        #endregion

    }
}
