#region Using Directives

using System;

#endregion

namespace ValidationFramework
{
	/// <summary>
	/// Performs a Range validation.
	/// Author: Steve Michelotti
	/// </summary>
	[AttributeUsage(AttributeTargets.Property)]
	public sealed class RangeValidatorAttribute : ValidatorAttribute
	{

		#region Private Fields

		private object min;
		private object max;

		#endregion


		#region Public Properties

		public object Minimum
		{
			get
			{
				return this.min;
			}
		}

		public object Maximum
		{
			get
			{
				return this.max;
			}
		}

		#endregion


		#region Constructors

		public RangeValidatorAttribute(object minimum, object maximum, string errorMessage) : base(errorMessage)
		{
            this.min = minimum;
            this.max = maximum;
		}

		#endregion
		
		
		#region Protected Overrides

        protected internal override bool EvaluateIsValid()
		{
            if (this.PropertyToValidate.Value == null || this.min == null || this.max == null)
				return true;

            if (PropertyToValidate.Type == typeof(string))
            {
                string minimum = this.min.ToString();
                string maximum = this.max.ToString();
                string value = PropertyToValidate.Value.ToString();
                return Validation.IsRangeValid(value, minimum, maximum);
            }
            else if (PropertyToValidate.Type == typeof(int))
            {
                int minimum = Convert.ToInt32(this.min);
                int maximum = Convert.ToInt32(this.max);
                int value = Convert.ToInt32(this.PropertyToValidate.Value);
                return Validation.IsRangeValid(value, minimum, maximum);
            }
            else if (PropertyToValidate.Type == typeof(decimal))
            {
                decimal minimum = Convert.ToDecimal(this.min);
                decimal maximum = Convert.ToDecimal(this.max);
                decimal value = Convert.ToDecimal(this.PropertyToValidate.Value);
                return Validation.IsRangeValid(value, minimum, maximum);
            }
            else if (PropertyToValidate.Type == typeof(DateTime))
            {
                DateTime minimum = Convert.ToDateTime(this.min);
                DateTime maximum = Convert.ToDateTime(this.max);
                DateTime value = Convert.ToDateTime(this.PropertyToValidate.Value);
                return Validation.IsRangeValid(value, minimum, maximum);
            }
            else if (PropertyToValidate.Type == typeof(double))
            {
                double minimum = Convert.ToDouble(this.min);
                double maximum = Convert.ToDouble(this.max);
                double value = Convert.ToDouble(this.PropertyToValidate.Value);
                return Validation.IsRangeValid(value, minimum, maximum);
            }
            else if (PropertyToValidate.Type == typeof(Nullable<int>))
            {
                int minimum = Convert.ToInt32(this.min);
                int maximum = Convert.ToInt32(this.max);
                Nullable<int> value = (Nullable<int>)this.PropertyToValidate.Value;
                return Validation.IsRangeValid(value, minimum, maximum);
            }
            else if (PropertyToValidate.Type == typeof(Nullable<DateTime>))
            {
                DateTime minimum = Convert.ToDateTime(this.min);
                DateTime maximum = Convert.ToDateTime(this.max);
                Nullable<DateTime> value = (Nullable<DateTime>)this.PropertyToValidate.Value;
                return Validation.IsRangeValid(value, minimum, maximum);
            }
            else if (PropertyToValidate.Type == typeof(Nullable<decimal>))
            {
                decimal minimum = Convert.ToDecimal(this.min);
                decimal maximum = Convert.ToDecimal(this.max);
                Nullable<decimal> value = (Nullable<decimal>)this.PropertyToValidate.Value;
                return Validation.IsRangeValid(value, minimum, maximum);
            }
            else if (PropertyToValidate.Type == typeof(Nullable<double>))
            {
                double minimum = Convert.ToDouble(this.min);
                double maximum = Convert.ToDouble(this.max);
                Nullable<double> value = (Nullable<double>)this.PropertyToValidate.Value;
                return Validation.IsRangeValid(value, minimum, maximum);
            }
            else
            {
                throw new ArgumentException(PropertyToValidate.Type.ToString() +
                    " is not a valid data type to be used with a Range Validator.");
            }
		}

		#endregion

	}//end class
}//end namespace
