#region Using Directives

using System;
using System.Text.RegularExpressions;

#endregion

namespace ValidationFramework
{
	/// <summary>
	/// Performs a Regular Expression validation.
	/// </summary>
	[AttributeUsage(AttributeTargets.Property)]
	public sealed class RegexValidatorAttribute : ValidatorAttribute
	{

		#region Private Fields

		private readonly string validationPattern;

		#endregion


		#region Constructors

		public RegexValidatorAttribute(string validationExpression, string errorMessage) : base(errorMessage)
		{
			this.validationPattern = validationExpression;
		}

		#endregion


		#region Public Properties

		public string ValidationExpression
		{
			get
			{
				return this.validationPattern;
			}
		}

		#endregion


		#region Protected Overrides

		protected internal override bool EvaluateIsValid()
		{
            if (this.PropertyToValidate.Type != typeof(string))
            {
                throw new ArgumentException("Property must be a string to be used for the Regex Validator");
            }

			string text = this.PropertyToValidate.Value as string;
			if (text == null)
				return true;

            return Validation.IsRegexValid(text, this.validationPattern);
		}

		#endregion

	}//end class
}//end namespace
