#region Using Directives

using System;
using System.Diagnostics.CodeAnalysis;
using System.Reflection;

#endregion

namespace ValidationFramework
{
	/// <summary>
	/// Base class for all valiator attributes.
	/// Author: Steve Michelotti
	/// </summary>
    [AttributeUsage(AttributeTargets.Property)]
    public abstract class ValidatorAttribute : Attribute
    {

	    #region Private Fields

        private bool isValid;

        //Make errMessage internal so that CustomValidatorAttribute can change it
        //but not protected because other sub-classed validators in external
        //assemblies should not be able to access it
	    internal string errMessage;
        
        private PropertyInfoExtended propertyToValidate;

	    #endregion


	    #region Public Properties

        public virtual string UniqueKey
        {
            get
            {
                return this.propertyToValidate.Name + this.ErrorMessage;
            }
        }

	    public bool IsValid
	    {
		    get { return this.isValid; }
            set { this.isValid = value; }
	    }


	    public string ErrorMessage
	    {
		    get { return this.errMessage; }
	    }

	    public string PropertyName
	    {
            get
            {
                return this.propertyToValidate.Name;
            }
	    }

        public PropertyInfoExtended PropertyToValidate
        {
            get { return propertyToValidate; }
            internal set { propertyToValidate = value; }
        }

	    #endregion


	    #region Constructors

	    protected ValidatorAttribute(string errorMessage)
	    {
		    this.errMessage = errorMessage;
	    }

	    //Hide default constructor
	    private ValidatorAttribute() {}

	    #endregion

    	
	    #region Public Methods

        public void Validate()
        {
            this.isValid = this.EvaluateIsValid();
        }

	    #endregion


	    #region Protected Methods

	    protected internal abstract bool EvaluateIsValid();

        #endregion

    }//end class    
}//end namespace
